﻿import es
import gamethread
import langlib
import playerlib
import popuplib

lang_dir = "cstrike/addons/eventscripts/soccer_mod_2010/language/"
popup_name = "sm_popup_admin_referee_warn"

messages = langlib.Strings(lang_dir + "referee/messages_referee_warn.ini")
messages_common = langlib.Strings(lang_dir + "messages_common.ini")

# ******************** Load ********************
def load():
	create_popup()

	es.addons.registerSayFilter(filter)

# ******************** Events ********************
def filter(userid, text, teamonly):
	steamid = es.getplayersteamid(userid)

	if es.exists("key", "sm_keygroup_set", steamid) == 1:
		text = text.strip('"')
		type = es.keygetvalue("sm_keygroup_set", steamid, "setting_type")
		if type == "referee_custom_warning":
			if text != "!cancel":
				warning(userid, es.keygetvalue("sm_keygroup_set", steamid, "userid"), text)
			else:
				popuplib.send(popup_name, userid)

			es.keydelete("sm_keygroup_set", steamid)
			return (0, None, 0)
		else:
			return (userid, text, teamonly)
	else:
		return (userid, text, teamonly)

# ******************** Create popup ********************
def create_popup():
	common = langlib.Strings(lang_dir + "popup_common.ini")
	text = langlib.Strings(lang_dir + "referee/popup_admin_referee_warn.ini")

	popup = popuplib.create(popup_name)

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")

	tokens = {}
	for i in range(1, 8):
		tokens["warning"] = es.ServerVar("sm_referee_warning_%s" % (i))
		popup.addline("->%s. %s" % (i, text("warning", tokens)))

	popup.addline("->8. %s" % (text("custom")))
	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("->0. %s" % (common("close")))

	popup.select(1, select_warning)
	popup.select(2, select_warning)
	popup.select(3, select_warning)
	popup.select(4, select_warning)
	popup.select(5, select_warning)
	popup.select(6, select_warning)
	popup.select(7, select_warning)
	popup.select(8, select_warning)
	popup.submenu(9, "sm_popup_admin_referee")

# ******************** Popup choice ********************
def select_warning(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	myPopup = popuplib.easymenu(name, None, player_choice)
	myPopup.settitle(messages("select_player"))

	if choice < 8:
		type = "warning_%s" % (choice)
	elif choice == 8:
		type = "custom_warning"

	for player in playerlib.getPlayerList("#human"):
		myPopup.addoption("%s_%s" % (type, player.userid), player.name)

	myPopup.submenu(10, popup_name)

	popuplib.send(name, userid)

# ******************** Easymenu choice ********************
def player_choice(userid, choice, keymenuname):
	type = choice.split("_")
	if type[0] == "warning":
		warning(userid, type[2], es.ServerVar("sm_referee_warning_%s" %(type[1])))
	elif type[0] == "custom":
		tokens = {}
		player = playerlib.getPlayer(userid)

		name = "sm_popup_%s" % (userid)
		if popuplib.exists(name):
			popuplib.delete(name)

		if es.exists("userid", type[2]) == 1:
			if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
				es.keycreate("sm_keygroup_set", player.steamid)

			es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "referee_custom_warning")
			es.keysetvalue("sm_keygroup_set", player.steamid, "userid", type[2])

			es.tell(userid, "#green", messages("set_warning", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages_common("no_player_found", tokens, player.get("lang")))
			popuplib.send(popup_name, userid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	for player in playerlib.getPlayerList("#human"):
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def warning(userid, choice, warn):
	tokens = {}
	player = playerlib.getPlayer(userid)

	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	if es.exists("userid", choice) == 1:
		target = playerlib.getPlayer(choice)

		es.cexec_all("playgamesound", es.ServerVar("sm_referee_sound_whistle"))

		tokens["name"] = player.name
		tokens["target"] = target.name
		tokens["warning"] = warn
		lang_msg("warn_message", tokens)

		es.menu(5, int(choice), messages("warning", tokens, target.get("lang")))

		es.centertell(choice, messages("warning", tokens, target.get("lang")))
		gamethread.delayed(1, es.centertell, (choice, messages("warning", tokens, target.get("lang"))))
		gamethread.delayed(2, es.centertell, (choice, messages("warning", tokens, target.get("lang"))))
		gamethread.delayed(3, es.centertell, (choice, messages("warning", tokens, target.get("lang"))))
		gamethread.delayed(4, es.centertell, (choice, messages("warning", tokens, target.get("lang"))))
	else:
		es.tell(userid, "#green", messages_common("no_player_found", tokens, player.get("lang")))

	popuplib.send(popup_name, userid)

# ******************** Unload ********************
def unload():
	es.addons.unregisterSayFilter(filter)

	popuplib.delete(popup_name)